aboutsummaryrefslogtreecommitdiff
path: root/helix-term/src/ui/editor.rs
diff options
context:
space:
mode:
authorGokul Soumya2021-08-21 05:21:20 +0000
committerGitHub2021-08-21 05:21:20 +0000
commitf9375f449c8b7bbf792c88b89903fe38d524f2e5 (patch)
tree71a2313a7a7cebc071dffd9e3423f407eb4192e0 /helix-term/src/ui/editor.rs
parentac8bc541087f815a026b4c664c069d8806b9c5de (diff)
Refactor new Rect construction (#575)
* Refactor new Rect construction Introduces methods that can be chained to construct new Rects out of pre-existing ones * Clamp x and y to edges in Rect chop methods * Rename Rect clipping functions
Diffstat (limited to 'helix-term/src/ui/editor.rs')
-rw-r--r--helix-term/src/ui/editor.rs24
1 files changed, 8 insertions, 16 deletions
diff --git a/helix-term/src/ui/editor.rs b/helix-term/src/ui/editor.rs
index b0e6de3e..d01d08e8 100644
--- a/helix-term/src/ui/editor.rs
+++ b/helix-term/src/ui/editor.rs
@@ -108,13 +108,11 @@ impl EditorView {
self.render_diagnostics(doc, view, inner, surface, theme);
- let area = Rect::new(
- view.area.x,
- view.area.y + view.area.height.saturating_sub(1),
- view.area.width,
- 1,
- );
- self.render_statusline(doc, view, area, surface, theme, is_focused);
+ let statusline_area = view
+ .area
+ .clip_top(view.area.height.saturating_sub(1))
+ .clip_bottom(1); // -1 from bottom to remove commandline
+ self.render_statusline(doc, view, statusline_area, surface, theme, is_focused);
}
/// Get syntax highlights for a document in a view represented by the first line
@@ -528,12 +526,7 @@ impl EditorView {
let width = 80.min(viewport.width);
let height = 15.min(viewport.height);
paragraph.render(
- Rect::new(
- viewport.right() - width,
- viewport.y as u16 + 1,
- width,
- height,
- ),
+ Rect::new(viewport.right() - width, viewport.y + 1, width, height),
surface,
);
}
@@ -572,7 +565,7 @@ impl EditorView {
theme.get("ui.statusline.inactive")
};
// statusline
- surface.set_style(Rect::new(viewport.x, viewport.y, viewport.width, 1), style);
+ surface.set_style(viewport.with_height(1), style);
if is_focused {
surface.set_string(viewport.x + 1, viewport.y, mode, style);
}
@@ -1001,8 +994,7 @@ impl Component for EditorView {
surface.set_style(area, cx.editor.theme.get("ui.background"));
// if the terminal size suddenly changed, we need to trigger a resize
- cx.editor
- .resize(Rect::new(area.x, area.y, area.width, area.height - 1)); // - 1 to account for commandline
+ cx.editor.resize(area.clip_bottom(1)); // -1 from bottom for commandline
for (view, is_focused) in cx.editor.tree.views() {
let doc = cx.editor.document(view.doc).unwrap();